@@ -1,4 +1,9 @@
-from django.conf.urls.defaults import patterns, url
+try:
+    # Django 1.4+
+    from django.conf.urls import patterns, url
+except ImportError: # pragma: no cover
+    # Django 1.3
+    from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('comps.views',
     url(r'^comps(?:/(?P<directory_slug>[\w\-]+))?/$',
